Dox class

Implemented types

Constructors

Dox()
factory

Properties

config ↔ AppConfig
get app config
getter/setter pair
doxServices ↔ List<DoxService>
list of services that need to run when creating isolate
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ioc ↔ IocContainer
global dox ioc containers
getter/setter pair
isolateId ↔ int
isolate Id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → DoxServer
get dox http server
no setter
websocket ↔ IDoxWebsocket?
websocket
getter/setter pair

Methods

addService(DoxService service) → void
add service that need to run on isolate spawn
addServices(List<DoxService> services) → void
####### functions need to run on isolate ####### add services that need to run on isolate spawn
initialize(AppConfig appConfig) → void
initialize dox application it load env and set config
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setWebsocket(IDoxWebsocket ws) → void
set websocket
override
startServer() → Future<void>
start dox server
startServices() → Future<void>
start service registered to dox this is internal core use only your app do not need to call this function
toString() → String
A string representation of this object.
inherited
totalIsolate(int value) → void
override total isolate from config default is 3

Operators

operator ==(Object other) → bool
The equality operator.
inherited