CacheDriverInterface class abstract

coverage:ignore-file

Implementers

Constructors

CacheDriverInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefix → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String
getter/setter pair

Methods

flush() → Future<void>
forever(String key, String value) → Future<void>
forget(String key) → Future<void>
get(String key) → Future
has(String key) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, String value, {Duration? duration}) → Future<void>
setTag(String tagName) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited