FileCacheDriver class

Implemented types

Constructors

FileCacheDriver({String tag = ''})
Store cache into file

Properties

folder → String
cache folder directory
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String
tag name
getter/setter pairoverride

Methods

flush() → Future<void>
flush all the cache
override
forever(String key, String value) → Future<void>
set key value into cache forever
override
forget(String key) → Future<void>
remove a key from cache
override
get(String key) → Future
get value from cache
override
has(String key) → Future<bool>
check value exist
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, String value, {Duration? duration}) → Future<void>
set key value into cache default duration 1 hour
override
setTag(String tagName) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited