QueryException class

Inheritance

Constructors

QueryException({String message = 'Error in sql query', String errorCode = 'sql_query_error', int code = HttpStatus.internalServerError})

Properties

code ↔ int
getter/setter pairinherited
errorCode ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
message ↔ dynamic
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited