FormRequest class abstract

Constructors

FormRequest()

Properties

body → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>
no setter
method → String
no setter
param → Map<String, dynamic>
no setter
query → Map<String, dynamic>
no setter
request ↔ DoxRequest
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
no setter

Methods

all() → Map<String, dynamic>
Get all request from body and query
auth<T>() → T?
get auth class
has(String key) → bool
check if input is present
Get header value
host() → String
get host
input(String key) → dynamic
Get request value
ip() → String
Get user IP
isFormData() → bool
check request data is form data
isJson() → bool
check request data is json data
mapInputs() → Map<String, String>
use this function to change request input name
messages() → Map<String, String>
set validation messages
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
only(List<String> keys) → Map<String, dynamic>
Get Only specific request from body and query
origin() → String?
get origin
referer() → String?
get origin
rules() → Map<String, String>
set validation rules
setRequest(DoxRequest req) → void
setUp() → dynamic
run on initial
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
userAgent() → String
get user agent from header`

Operators

operator ==(Object other) → bool
The equality operator.
inherited