DoxResponse class

Constructors

DoxResponse(dynamic _contentData)
content can be anything String, int, Map, json serializable object, Stream<List

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cache(Duration duration) → DoxResponse
set cache
content(dynamic content) → DoxResponse
Set response status code default 200
contentType(ContentType contentType) → DoxResponse
set content type such as json, text, html
Set cookie
getContent() → dynamic
Get original content data
set headers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(HttpRequest request) → dynamic
This function is for internal use only
statusCode(int code) → DoxResponse
Set response status code default 200
stream(Stream<List<int>> stream) → DoxResponse
set stream data to response
toString() → String
A string representation of this object.
inherited
withHeaders(Map<String, dynamic> values) → DoxResponse
Set list of headers by Map

Operators

operator ==(Object other) → bool
The equality operator.
inherited