AppConfig class

Constructors

AppConfig({required String appKey, int serverPort = 3000, int totalIsolate = 3, List<DoxService> services = const <DoxService>[], Map<Type, FormRequest Function()> formRequests = const <Type, FormRequest Function()>{}, List globalMiddleware = const <dynamic>[], List<Router> routers = const <Router>[], CORSConfig cors = const CORSConfig(), LoggerConfig logger = const LoggerConfig(), CacheConfig cache = const CacheConfig(), FileStorageConfig fileStorage = const FileStorageConfig(), dynamic errorHandler(Object?, StackTrace) = defaultErrorHandler, ResponseHandlerInterface? responseHandler})

Properties

appKey → String
final
cache → CacheConfig
final
cors → CORSConfig
final
errorHandler → dynamic Function(Object?, StackTrace)
final
fileStorage → FileStorageConfig
final
formRequests → Map<Type, FormRequest Function()>
final
globalMiddleware → List
final
hashCode → int
The hash code for this object.
no setterinherited
logger → LoggerConfig
final
responseHandler → ResponseHandlerInterface?
final
routers → List<Router>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverPort → int
final
services → List<DoxService>
final
totalIsolate → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited