CORSConfig class

Constructors

CORSConfig({bool enabled = true, dynamic origin, dynamic methods, dynamic headers, dynamic exposeHeaders, bool? credentials, num? maxAge})
const

Properties

credentials → bool?
final
enabled → bool
final
exposeHeaders → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
headers → dynamic
final
maxAge → num?
final
methods → dynamic
final
origin → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited