LoggerConfig class

Constructors

LoggerConfig({String name = '', bool enabled = false, bool prettyPrint = false, String level = 'info'})
const

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
level → String
final
name → String
final
prettyPrint → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited