DoxIsolate class

Constructors

DoxIsolate()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isolates → Map<int, Isolate>
get list of running isolates
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPorts → Map<int, SendPort>
no setter

Methods

killAll() → void
kill all the isolate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
spawn(int count) → Future<void>
create threads
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited