IsolateSpawnParameter class

Constructors

IsolateSpawnParameter(int isolateId, AppConfig config, List<DoxService> services, {List<RouteData> routes = const <RouteData>[]})
const

Properties

config → AppConfig
final
hashCode → int
The hash code for this object.
no setterinherited
isolateId → int
final
routes → List<RouteData>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<DoxService>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited