DownloadableFile class

Constructors

DownloadableFile(ContentType contentType, Stream<List<int>> stream, String filename)

Properties

contentDisposition ↔ String
getter/setter pair
contentType → ContentType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream → Stream<List<int>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited